@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-from .version import __version__
-
 __package_name__ = "myrich"
+from .version import __version__
+from .__main__ import main
 
-__all__ = ["__package_name__", "__version__"]
+__all__ = ["main", "__package_name__", "__version__"]
